@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import CollectionCounts from 'gmp/collection/collectioncounts';
+import CollectionCounts from 'gmp/collection/CollectionCounts';
 import {parseCollectionList} from 'gmp/collection/parser';
 import registerCommand from 'gmp/command';
 import EntitiesCommand from 'gmp/commands/entities';
@@ -12,7 +12,6 @@ import logger from 'gmp/log';
 import Filter from 'gmp/models/filter';
 import {isDefined} from 'gmp/utils/identity';
 
-
 const log = logger.getLogger('gmp.commands.filters');
 
 class FilterCommand extends EntityCommand {
@@ -98,8 +97,8 @@ class FiltersCommand extends EntitiesCommand {
     const response = this.getEntitiesResponse(root);
     return parseCollectionList(response, this.name, this.clazz, {
       meta,
-      filter_parse_func: parseFilter,
-      collection_count_parse_func: parse_collection_counts,
+      filterParseFunc: parseFilter,
+      collectionCountParseFunc: parse_collection_counts,
     });
   }
 }
