@@ -4,12 +4,10 @@
  */
 
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
 import Vulnerability from 'gmp/models/vulnerability';
 
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
-
 class VulnerabilityCommand extends EntityCommand {
   constructor(http) {
     super(http, 'vuln', Vulnerability);
@@ -44,5 +42,3 @@ class VulnerabilitiesCommand extends EntitiesCommand {
 
 registerCommand('vuln', VulnerabilityCommand);
 registerCommand('vulns', VulnerabilitiesCommand);
-
-// vim: set ts=2 sw=2 tw=80:
