@@ -3,47 +3,40 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import Model, {
-  ModelElement,
-  ModelProperties,
-  parseModelFromElement,
-} from 'gmp/model';
+import EntityModel, {parseEntityModelProperties} from 'gmp/models/entitymodel';
 import convert from 'gmp/models/filter/convert';
 import FilterTerm, {AND} from 'gmp/models/filter/filterterm';
 import {EXTRA_KEYWORDS} from 'gmp/models/filter/keywords';
-import {parseInt, setProperties} from 'gmp/parser';
+import Model, {ModelElement, ModelProperties} from 'gmp/models/model';
+import {parseInt} from 'gmp/parser';
 import {map} from 'gmp/utils/array';
 import {isDefined, isString, isArray, hasValue} from 'gmp/utils/identity';
 
-export const UNKNOWN_FILTER_ID = '0';
-const SORT_ORDER_ASC = 'sort';
-const SORT_ORDER_DESC = 'sort-reverse';
-
-interface FilterKeyword {
-  column: string;
-  relation: string;
-  value: string;
+export interface FilterKeyword {
+  column?: string;
+  relation?: string;
+  value?: string;
 }
 
-interface FilterModelProperties extends ModelProperties {
-  _term?: string;
-  alerts?: ModelElement[];
-  filter_type?: string;
-  terms: FilterTerm[];
-}
-
-interface FilterModelElement extends ModelElement {
+export interface FilterModelElement extends ModelElement {
   alerts?: {
-    alert: ModelProperties[];
+    alert: ModelElement[];
   };
   filter_type?: string;
   keywords?: {
-    keyword: FilterKeyword[];
+    keyword?: FilterKeyword | FilterKeyword[];
   };
   term?: string;
 }
 
-type SortOrder = typeof SORT_ORDER_ASC | typeof SORT_ORDER_DESC;
+interface FilterModelProperties extends ModelProperties {
+  _term?: string;
+  alerts?: Model[];
+  filter_type?: string;
+  terms?: FilterTerm[];
+}
+
+export type FilterSortOrder = typeof SORT_ORDER_ASC | typeof SORT_ORDER_DESC;
 
 type FilterForEachFunc = (
   value: FilterTerm,
@@ -51,6 +44,10 @@ type FilterForEachFunc = (
   array: FilterTerm[],
 ) => void;
 
+export const UNKNOWN_FILTER_ID = '0';
+const SORT_ORDER_ASC = 'sort';
+const SORT_ORDER_DESC = 'sort-reverse';
+
 /**
  * Parses FilterTerms from filterString
  *
@@ -96,41 +93,64 @@ const parseFilterTermsFromString = (
 
 /**
  * Represents a filter
- *
- * @extends Model
  */
-class Filter extends Model {
-  static entityType = 'filter';
-  terms: FilterTerm[];
-  filter_type!: string;
-  alerts?: ModelElement[];
+class Filter extends EntityModel {
+  static readonly entityType: string = 'filter';
 
-  constructor() {
-    super();
+  readonly alerts: Model[];
+  readonly filter_type?: string;
+  readonly terms: FilterTerm[];
 
-    this.terms = [];
+  constructor({
+    _type,
+    alerts = [],
+    comment,
+    creationTime,
+    // eslint-disable-next-line @typescript-eslint/naming-convention
+    filter_type,
+    id,
+    inUse,
+    modificationTime,
+    name,
+    owner,
+    terms = [],
+    userCapabilities,
+    userTags = [],
+    writable,
+  }: FilterModelProperties = {}) {
+    super({
+      _type,
+      comment,
+      creationTime,
+      id,
+      inUse,
+      modificationTime,
+      name,
+      owner,
+      userCapabilities,
+      userTags,
+      writable,
+    });
+
+    this.alerts = alerts;
+    this.filter_type = filter_type;
+    this.terms = terms;
   }
 
   get length() {
     return this.terms.length;
   }
 
-  setProperties({id, ...properties}: FilterModelProperties) {
-    // override setProperties to allow changing the id
-    setProperties(properties, this);
-    this.id = id;
-    return this;
-  }
-
   /**
-   * Parse properties from the passed element object
+   * Create new Filter from the passed element object
    *
-   * @param element  Element object to parse properties from.
+   * @override
+   * @param element Element object to parse properties from.
    *
    * @return An object with properties for the new Filter model
    */
-  static parseElement(element: FilterModelElement = {}): FilterModelProperties {
-    const ret = super.parseElement(element) as FilterModelProperties;
+  static fromElement(element: FilterModelElement = {}): Filter {
+    const ret = parseEntityModelProperties(element) as FilterModelProperties;
 
     ret.filter_type = ret._type;
 
@@ -158,12 +178,12 @@ class Filter extends Model {
     }
 
     if (isDefined(element.alerts?.alert)) {
-      ret.alerts = map(element.alerts.alert, (alert: ModelElement) =>
-        parseModelFromElement(alert, 'alert'),
+      ret.alerts = map(element.alerts.alert, alert =>
+        Model.fromElement(alert, 'alert'),
       );
     }
 
-    return ret;
+    return new Filter(ret);
   }
 
   /**
@@ -212,20 +232,6 @@ class Filter extends Model {
     return this;
   }
 
-  /**
-   * Set the FilterTerm array of this Filter
-   *
-   * @private
-   *
-   * @param terms Array of FilterTerms to set.
-   *
-   * @return This filter
-   */
-  _setTerms(terms: FilterTerm[]) {
-    this.terms = terms;
-    return this;
-  }
-
   /**
    * Get the first index of the FilterTerm with key as keyword
    *
@@ -299,6 +305,7 @@ class Filter extends Model {
    * @return This filter.
    */
   _resetFilterId() {
+    // @ts-expect-error
     this.id = undefined;
     return this;
   }
@@ -385,7 +392,7 @@ class Filter extends Model {
       return false;
     }
     const terms = this.getTerms(term.keyword);
-    return terms.findIndex(cterm => cterm.equals(term)) !== -1;
+    return terms.findIndex(currentTerm => currentTerm.equals(term)) !== -1;
   }
 
   /**
@@ -429,7 +436,10 @@ class Filter extends Model {
    * @return Returns the first FilterTerm value for the passed keyword
    *         or def if no FilterTerm for the keyword exists in this Filter.
    */
-  get(key: string, def: string | undefined = undefined): string | undefined {
+  get(
+    key: string,
+    def: string | undefined = undefined,
+  ): string | number | undefined {
     const term = this.getTerm(key);
     return isDefined(term) ? term.value : def;
   }
@@ -445,7 +455,7 @@ class Filter extends Model {
    *
    * @return This filter
    */
-  set(keyword: string, value?: string, relation: string = '=') {
+  set(keyword: string, value?: string | number, relation: string = '=') {
     this._resetFilterId(); // reset id because the filter has changed
     const converted = convert(keyword, value, relation);
     this._setTerm(new FilterTerm(converted));
@@ -482,6 +492,15 @@ class Filter extends Model {
     return this;
   }
 
+  /**
+   * Provides a unique identifier string for the filter
+   *
+   * @returns A string representation of this filter to be used as an identifier
+   */
+  identifier() {
+    return this.toFilterString();
+  }
+
   /**
    * Compare this filter with another filter
    *
@@ -537,14 +556,13 @@ class Filter extends Model {
    * @return A shallow copy of this filter.
    */
   copy(): Filter {
-    const f = new Filter();
-
-    // copy public properties
-    f.id = this.id;
-    f.filter_type = this.filter_type;
-
-    f._setTerms([...this.getAllTerms()]);
-    return f;
+    return new Filter({
+      id: this.id,
+      filter_type: this.filter_type,
+      terms: [...this.getAllTerms()],
+      userCapabilities: this.userCapabilities,
+      userTags: this.userTags,
+    });
   }
 
   /**
@@ -677,20 +695,20 @@ class Filter extends Model {
   /**
    * Returns the sort order of the current filter
    *
-   * @return {String} The sort order. 'sort' or 'sort-reverse'.
+   * @return The sort order. 'sort' or 'sort-reverse'.
    */
-  getSortOrder(): SortOrder {
+  getSortOrder(): FilterSortOrder {
     return this.has(SORT_ORDER_DESC) ? SORT_ORDER_DESC : SORT_ORDER_ASC;
   }
 
   /**
    * Returns the sort by field name of the current filter
    *
-   * @return The sort order. 'sort' or 'sort-reverse'.
+   * @return The sort field name or undefined if no sort field is set.
    */
   getSortBy(): string | undefined {
     const order = this.getSortOrder();
-    return this.get(order);
+    return this.get(order) as string | undefined;
   }
 
   /**
@@ -700,7 +718,7 @@ class Filter extends Model {
    *
    * @return This filter.
    */
-  setSortOrder(value: SortOrder) {
+  setSortOrder(value: FilterSortOrder) {
     const sortby = this.getSortBy();
     value = value === SORT_ORDER_DESC ? SORT_ORDER_DESC : SORT_ORDER_ASC;
     this.set(value, sortby);
@@ -758,11 +776,11 @@ class Filter extends Model {
    * created and returned. Only extra keywords not included in this filter will
    * be merged.
    *
-   * @param filter  Use extra params terms filter to be merged.
+   * @param filter Use extra params terms filter to be merged.
    *
    * @return A new filter with merged terms.
    */
-  mergeExtraKeywords(filter: Filter): Filter {
+  mergeExtraKeywords(filter?: Filter): Filter {
     const f = this.copy();
     f._resetFilterId();
     return f._mergeExtraKeywords(filter);
@@ -778,9 +796,10 @@ class Filter extends Model {
    * @return New Filter with FilterTerms parsed from filterString.
    */
   static fromString(filterString?: string, filter?: Filter): Filter {
-    const f = new Filter();
+    const f = new Filter({
+      terms: parseFilterTermsFromString(filterString),
+    });
 
-    f._setTerms(parseFilterTermsFromString(filterString));
     f._mergeExtraKeywords(filter);
 
     return f;
@@ -794,13 +813,15 @@ class Filter extends Model {
    * @returns The new Filter
    */
   static fromTerm(...term: FilterTerm[]): Filter {
-    const f = new Filter();
-    return f._addTerm(...term);
+    return new Filter({
+      terms: term,
+    });
   }
 }
 
 export const ALL_FILTER = new Filter().all();
 export const ALERTS_FILTER_FILTER = Filter.fromString('type=alert');
+export const AUDITS_FILTER_FILTER = Filter.fromString('type=task');
 export const AUDIT_REPORTS_FILTER_FILTER =
   Filter.fromString('type=audit_report');
 export const CERTBUND_FILTER_FILTER = Filter.fromString('type=info');
@@ -816,6 +837,7 @@ export const NVTS_FILTER_FILTER = Filter.fromString('type=info');
 export const OS_FILTER_FILTER = Filter.fromString('type=os');
 export const OVERRIDES_FILTER_FILTER = Filter.fromString('type=override');
 export const PORTLISTS_FILTER_FILTER = Filter.fromString('type=port_list');
+export const POLICIES_FILTER_FILTER = Filter.fromString('type=config');
 export const PERMISSIONS_FILTER_FILTER = Filter.fromString('type=permission');
 export const REPORT_CONFIGS_FILTER_FILTER =
   Filter.fromString('type=report_config');
