@@ -3,12 +3,12 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import hoistStatics from 'hoist-non-react-statics';
 import React from 'react';
+import hoistStatics from 'hoist-non-react-statics';
 import FilterSelection from 'web/components/dashboard/display/FilterSelection';
+import {updateDisplayName} from 'web/utils/displayName';
 import PropTypes from 'web/utils/PropTypes';
 
-
 const withFilterSelection =
   ({filtersFilter}) =>
   Component => {
@@ -32,7 +32,14 @@ const withFilterSelection =
       showFilterSelection: PropTypes.bool,
     };
 
-    return hoistStatics(FilterSelectionWrapper, Component);
+    return hoistStatics(
+      updateDisplayName(
+        FilterSelectionWrapper,
+        Component,
+        'withFilterSelection',
+      ),
+      Component,
+    );
   };
 
 export default withFilterSelection;
