@@ -3,10 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
+import {isDefined} from 'gmp/utils/identity';
 import MessageContainer from 'web/components/error/MessageContainer';
-import StNonAvailableIcon from 'web/components/icon/StNonAvailableIcon';
+import {StNonAvailableIcon} from 'web/components/icon';
 import Divider from 'web/components/layout/Divider';
 import Layout, {LayoutProps} from 'web/components/layout/Layout';
 
