@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
+import {render} from 'web/testing';
 import ErrorContainer from 'web/components/error/ErrorContainer';
-import {render} from 'web/utils/Testing';
-
 
 describe('ErrorContainer tests', () => {
   test('should render', () => {
