@@ -3,18 +3,20 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import React, {useRef, useCallback} from 'react';
 import logger from 'gmp/log';
 import {hasValue} from 'gmp/utils/identity';
-import React, {useRef, useCallback} from 'react';
 import Download from 'web/components/form/Download';
 
-const log = logger.getLogger('web.components.form.useDownload');
-
-type DownloadFunc = (params: {
+type DownloadParams = {
   filename: string;
   data: string;
-  mimetype: string;
-}) => void;
+  mimetype?: string;
+};
+
+export type DownloadFunc = (params: DownloadParams) => void;
+
+const log = logger.getLogger('web.components.form.useDownload');
 
 /**
  * Hook to download a file
@@ -29,7 +31,7 @@ const useDownload = (): [
 ] => {
   const downloadRef = useRef<Download | null>(null);
 
-  const download = useCallback(({filename, data, mimetype}) => {
+  const download = useCallback(({filename, data, mimetype}: DownloadParams) => {
     if (!hasValue(downloadRef.current)) {
       log.warn('Download ref not set.');
       return;
