@@ -3,13 +3,12 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
 import styled from 'styled-components';
+import {isDefined} from 'gmp/utils/identity';
 import Img from 'web/components/img/Img';
 import useGmp from 'web/hooks/useGmp';
-
+import useTranslation from 'web/hooks/useTranslation';
 
 const Image = styled(Img)`
   display: flex;
@@ -17,10 +16,11 @@ const Image = styled(Img)`
 `;
 
 const ProductImage = props => {
+  const [_] = useTranslation();
   const {settings} = useGmp();
   return (
     <Image
-      alt={_('Greenbone Security Assistant')}
+      alt={_('OPENVAS SCAN')}
       {...props}
       src={
         isDefined(settings) && isDefined(settings.vendorLabel)
