@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
+import {rendererWith} from 'web/testing';
 import ProductImage from 'web/components/img/Product';
-import {rendererWith} from 'web/utils/Testing';
-
 
 describe('ProductImage tests', () => {
   test('should render', () => {
