@@ -7,18 +7,18 @@ import React from 'react';
 import styled from 'styled-components';
 import Layout, {LayoutProps} from 'web/components/layout/Layout';
 
-const DEFAULT_MARGIN = '5px';
-
 interface DividerComponentProps {
   flex?: string;
   $margin: string;
 }
 
-interface DividerProps extends LayoutProps {
+export interface DividerProps extends LayoutProps {
   flex?: string;
   margin?: string;
 }
 
+const DEFAULT_MARGIN = '5px';
+
 const DividerComponent = styled(Layout)<DividerComponentProps>`
   & > * {
     display: inline-flex;
@@ -45,7 +45,7 @@ const DividerContainer = styled(Layout)`
 
 DividerContainer.displayName = 'DividerContainer';
 
-const Divider: React.FC<DividerProps> = ({
+const Divider = ({
   margin = DEFAULT_MARGIN,
   grow,
   flex,
