@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
+import {render} from 'web/testing';
 import Portal from 'web/components/portal/Portal';
-import {render} from 'web/utils/Testing';
-
 
 describe('Portal component tests', () => {
   test('should render portal', () => {
