@@ -13,12 +13,12 @@ interface TableProps {
   header?: React.ReactNode;
 }
 
-const Table: React.FC<TableProps> = ({
-  children,
-  className,
-  footer,
-  header,
-}: TableProps) => {
+interface StyledTableProps {
+  $fixed?: boolean;
+  $size?: string;
+}
+
+const Table = ({children, className, footer, header}: TableProps) => {
   return (
     <table className={className}>
       {header}
@@ -28,11 +28,6 @@ const Table: React.FC<TableProps> = ({
   );
 };
 
-interface StyledTableProps {
-  $fixed?: boolean;
-  $size?: string;
-}
-
 export default styled(Table)<StyledTableProps>`
   border: 0;
   border-spacing: 0px;
