@@ -7,8 +7,14 @@ import React from 'react';
 import Layout from 'web/components/layout/Layout';
 import PropTypes from 'web/utils/PropTypes';
 
-const DetailsBlock = ({id, children, className, title}) => (
-  <Layout className={className} flex="column" id={id}>
+const DetailsBlock = ({
+  id,
+  children,
+  className,
+  title,
+  'data-testid': dataTestId,
+}) => (
+  <Layout className={className} data-testid={dataTestId} flex="column" id={id}>
     <h2>{title}</h2>
     <div>{children}</div>
   </Layout>
@@ -16,6 +22,7 @@ const DetailsBlock = ({id, children, className, title}) => (
 
 DetailsBlock.propTypes = {
   className: PropTypes.string,
+  'data-testid': PropTypes.string,
   id: PropTypes.string,
   title: PropTypes.string.isRequired,
 };
