@@ -3,16 +3,15 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
 import React from 'react';
-import DetailsIcon from 'web/components/icon/DetailsIcon';
+import {DetailsIcon} from 'web/components/icon';
 import IconDivider from 'web/components/layout/IconDivider';
 import DetailsLink from 'web/components/link/DetailsLink';
 import EntityBox from 'web/entity/Box';
+import useTranslation from 'web/hooks/useTranslation';
 import PropTypes from 'web/utils/PropTypes';
-
-
 const NoteBox = ({note, detailsLink = true}) => {
+  const [_] = useTranslation();
   const toolbox = detailsLink ? (
     <IconDivider>
       <DetailsLink id={note.id} title={_('Note Details')} type="note">
