@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
+import {render} from 'web/testing';
 import DetailsBlock from 'web/entity/Block';
-import {render} from 'web/utils/Testing';
-
 
 describe('Entity Block component tests', () => {
   test('should render', () => {
