@@ -7,9 +7,9 @@ import React from 'react';
 import SeverityBar from 'web/components/bar/SeverityBar';
 import Comment from 'web/components/comment/Comment';
 import DateTime from 'web/components/date/DateTime';
-import TableData from 'web/components/table/Data';
-import TableRow from 'web/components/table/Row';
-import EntitiesActions from 'web/entities/Actions';
+import TableData from 'web/components/table/TableData';
+import TableRow from 'web/components/table/TableRow';
+import EntitiesActions from 'web/entities/EntitiesActions';
 import RowDetailsToggle from 'web/entities/RowDetailsToggle';
 import PropTypes from 'web/utils/PropTypes';
 import {na} from 'web/utils/Render';
@@ -33,7 +33,7 @@ const Row = ({
     <TableData>
       <DateTime date={entity.modificationTime} />
     </TableData>
-    <TableData>{entity.cve_refs}</TableData>
+    <TableData>{entity.cveRefs}</TableData>
     <TableData>
       <SeverityBar severity={entity.severity} />
     </TableData>
