@@ -3,18 +3,19 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
-import TableBody from 'web/components/table/Body';
-import TableData from 'web/components/table/Data';
-import TableHead from 'web/components/table/Head';
-import TableHeader from 'web/components/table/Header';
-import TableRow from 'web/components/table/Row';
+import {isDefined} from 'gmp/utils/identity';
 import Table from 'web/components/table/StripedTable';
+import TableBody from 'web/components/table/TableBody';
+import TableData from 'web/components/table/TableData';
+import TableHead from 'web/components/table/TableHead';
+import TableHeader from 'web/components/table/TableHeader';
+import TableRow from 'web/components/table/TableRow';
+import useTranslation from 'web/hooks/useTranslation';
 import PropTypes from 'web/utils/PropTypes';
 
 const Preferences = ({preferences = [], defaultTimeout}) => {
+  const [_] = useTranslation();
   return (
     <Table>
       <TableHeader>
@@ -30,12 +31,14 @@ const Preferences = ({preferences = [], defaultTimeout}) => {
             {isDefined(defaultTimeout) ? defaultTimeout : _('default')}
           </TableData>
         </TableRow>
-        {preferences.map(pref => (
-          <TableRow key={pref.name}>
-            <TableData>{pref.hr_name}</TableData>
-            <TableData>{pref.default}</TableData>
-          </TableRow>
-        ))}
+        {preferences.map(pref => {
+          return (
+            <TableRow key={pref.name}>
+              <TableData>{pref.hr_name}</TableData>
+              <TableData>{pref.default}</TableData>
+            </TableRow>
+          );
+        })}
       </TableBody>
     </Table>
   );
