@@ -3,17 +3,16 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
+import {isDefined} from 'gmp/utils/identity';
 import SolutionTypeIcon from 'web/components/icon/SolutionTypeIcon';
 import IconDivider from 'web/components/layout/IconDivider';
 import DetailsBlock from 'web/entity/Block';
+import useTranslation from 'web/hooks/useTranslation';
 import Pre from 'web/pages/nvts/Preformatted';
 import PropTypes from 'web/utils/PropTypes';
-
-
 const Solution = ({solutionDescription, solutionType}) => {
+  const [_] = useTranslation();
   const hasSolution = isDefined(solutionDescription) || isDefined(solutionType);
 
   if (!hasSolution) {
