@@ -4,8 +4,8 @@
  */
 
 import {_l} from 'gmp/locale/lang';
-import {createEntitiesFooter} from 'web/entities/Footer';
-import {createEntitiesTable} from 'web/entities/Table';
+import createEntitiesFooter from 'web/entities/createEntitiesFooter';
+import createEntitiesTable from 'web/entities/createEntitiesTable';
 import withRowDetails from 'web/entities/withRowDetails';
 import PolicyDetails from 'web/pages/policies/Details';
 import Header from 'web/pages/policies/Header';
