@@ -4,16 +4,16 @@
  */
 
 import {describe, test, expect, testing} from '@gsa/testing';
+import {rendererWith, fireEvent, screen} from 'web/testing';
+import {vi} from 'vitest';
 import Capabilities from 'gmp/capabilities/capabilities';
-import CollectionCounts from 'gmp/collection/collectioncounts';
+import CollectionCounts from 'gmp/collection/CollectionCounts';
 import Filter from 'gmp/models/filter';
 import Policy from 'gmp/models/policy';
-import {vi} from 'vitest';
 import {currentSettingsDefaultResponse} from 'web/pages/__mocks__/CurrentSettings';
 import DetailsPage, {ToolBarIcons} from 'web/pages/policies/DetailsPage';
 import {entityLoadingActions} from 'web/store/entities/policies';
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
-import {rendererWith, fireEvent, screen} from 'web/utils/Testing';
 
 vi.mock('web/pages/scanconfigs/EditDialog', () => ({
   default: () => null,
@@ -197,10 +197,6 @@ const currentSettings = testing
   .fn()
   .mockResolvedValue(currentSettingsDefaultResponse);
 
-const renewSession = testing.fn().mockResolvedValue({
-  foo: 'bar',
-});
-
 const getPermissions = testing.fn().mockResolvedValue({
   data: [],
   meta: {
@@ -294,7 +290,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -378,7 +373,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -433,7 +427,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -509,7 +502,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -604,7 +596,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -708,7 +699,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
@@ -803,7 +793,6 @@ describe('Policy DetailsPage tests', () => {
       settings: {manualUrl},
       user: {
         currentSettings,
-        renewSession,
       },
     };
 
