@@ -3,6 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import React, {useEffect, useState} from 'react';
+import {useDispatch, useSelector, shallowEqual} from 'react-redux';
+import {useParams} from 'react-router';
 import logger from 'gmp/log';
 import Filter, {
   ALL_FILTER,
@@ -12,22 +15,19 @@ import Filter, {
 import {isActive} from 'gmp/models/task';
 import {first} from 'gmp/utils/array';
 import {isDefined, hasValue} from 'gmp/utils/identity';
-import React, {useEffect, useState} from 'react';
-import {useDispatch, useSelector, shallowEqual} from 'react-redux';
-import {useParams} from 'react-router';
 import withDownload from 'web/components/form/withDownload';
 import PageTitle from 'web/components/layout/PageTitle';
 import Reload, {
   NO_RELOAD,
   USE_DEFAULT_RELOAD_INTERVAL_ACTIVE,
 } from 'web/components/loading/Reload';
-import withDialogNotification from 'web/components/notification/withDialogNotifiaction';
+import withDialogNotification from 'web/components/notification/withDialogNotification';
 import FilterProvider from 'web/entities/FilterProvider';
 import useGmp from 'web/hooks/useGmp';
 import useTranslation from 'web/hooks/useTranslation';
 import Page from 'web/pages/reports/AuditDetailsContent';
-import FilterDialog from 'web/pages/reports/DetailsFilterDialog';
 import DownloadReportDialog from 'web/pages/reports/DownloadReportDialog';
+import ReportDetailsFilterDialog from 'web/pages/reports/ReportDetailsFilterDialog';
 import TargetComponent from 'web/pages/targets/Component';
 import {
   loadAllEntities as loadFilters,
@@ -47,7 +47,6 @@ import {pageFilter as setPageFilter} from 'web/store/pages/actions';
 import getPage from 'web/store/pages/selectors';
 import {
   loadReportComposerDefaults,
-  renewSessionTimeout,
   saveReportComposerDefaults,
 } from 'web/store/usersettings/actions';
 import {getUserSettingsDefaultFilter} from 'web/store/usersettings/defaultfilters/selectors';
@@ -62,7 +61,6 @@ import compose from 'web/utils/Compose';
 import PropTypes from 'web/utils/PropTypes';
 import {generateFilename} from 'web/utils/Render';
 
-
 const log = logger.getLogger('web.pages.auditreport./DetailsPage');
 
 const DEFAULT_FILTER = Filter.fromString(
@@ -84,7 +82,6 @@ const getTarget = (entity = {}) => {
 };
 
 const ReportDetails = props => {
-  const [activeTab, setActiveTab] = useState(0);
   const [showFilterDialog, setShowFilterDialog] = useState(false);
   const [showDownloadReportDialog, setShowDownloadReportDialog] =
     useState(false);
@@ -289,7 +286,6 @@ const ReportDetails = props => {
   };
 
   const handleFilterChange = filter => {
-    handleInteraction();
     load(filter);
   };
 
@@ -305,16 +301,9 @@ const ReportDetails = props => {
     }
   };
 
-  const handleActivateTab = index => {
-    handleInteraction();
-    setActiveTab(index);
-  };
-
   const handleAddToAssets = () => {
     const {showSuccessMessage, reportFilter: filter} = props;
 
-    handleInteraction();
-
     gmp.auditreport.addAssets(selectedEntity, {filter}).then(() => {
       showSuccessMessage(
         _(
@@ -328,8 +317,6 @@ const ReportDetails = props => {
   const handleRemoveFromAssets = () => {
     const {showSuccessMessage, reportFilter: filter} = props;
 
-    handleInteraction();
-
     gmp.auditreport.removeAssets(selectedEntity, {filter}).then(() => {
       showSuccessMessage(_('Report content removed from Assets.'));
       reload();
@@ -337,12 +324,10 @@ const ReportDetails = props => {
   };
 
   const handleFilterEditClick = () => {
-    handleInteraction();
     setShowFilterDialog(true);
   };
 
   const handleFilterDialogClose = () => {
-    handleInteraction();
     setShowFilterDialog(false);
   };
 
@@ -388,8 +373,6 @@ const ReportDetails = props => {
       ? report_format.extension
       : 'unknown'; // unknown should never happen but we should be save here
 
-    handleInteraction();
-
     return gmp.auditreport
       .download(selectedEntity, {
         reportFormatId,
@@ -419,8 +402,6 @@ const ReportDetails = props => {
 
     const {data, serial} = cert;
 
-    handleInteraction();
-
     onDownload({
       filename: 'tls-cert-' + serial + '.pem',
       mimetype: 'application/x-x509-ca-cert',
@@ -429,7 +410,6 @@ const ReportDetails = props => {
   };
 
   const handleFilterCreated = filter => {
-    handleInteraction();
     load(filter);
     dispatch(loadFilters(gmp)(RESULTS_FILTER_FILTER));
   };
@@ -437,8 +417,6 @@ const ReportDetails = props => {
   const handleFilterDecreaseMinQoD = () => {
     const {reportFilter: filter} = props;
 
-    handleInteraction();
-
     if (filter.has('min_qod')) {
       const lfilter = filter.copy();
       lfilter.set('min_qod', 30);
@@ -447,8 +425,6 @@ const ReportDetails = props => {
   };
 
   const handleSortChange = (name, sortField) => {
-    handleInteraction();
-
     const prev = sorting[name];
 
     const sortReverse =
@@ -464,8 +440,6 @@ const ReportDetails = props => {
     setSorting(newSort);
   };
 
-  const handleInteraction = () => dispatch(renewSessionTimeout(gmp)());
-
   const loadTarget = () => {
     const target = getTarget(selectedEntity);
     return gmp.target.get({id: target.id});
@@ -491,10 +465,9 @@ const ReportDetails = props => {
   return (
     <React.Fragment>
       <PageTitle title={_('Report Details')} />
-      <TargetComponent onError={handleError} onInteraction={handleInteraction}>
+      <TargetComponent onError={handleError}>
         {({edit}) => (
           <Page
-            activeTab={activeTab}
             audit={true}
             entity={entity}
             errorsCounts={errorsCounts}
@@ -516,7 +489,6 @@ const ReportDetails = props => {
             sorting={sorting}
             task={isDefined(report) ? report.task : undefined}
             tlsCertificatesCounts={tlsCertificatesCounts}
-            onActivateTab={handleActivateTab}
             onAddToAssetsClick={handleAddToAssets}
             onError={handleError}
             onFilterChanged={handleFilterChange}
@@ -525,7 +497,6 @@ const ReportDetails = props => {
             onFilterEditClick={handleFilterEditClick}
             onFilterRemoveClick={handleFilterRemoveClick}
             onFilterResetClick={handleFilterResetClick}
-            onInteraction={handleInteraction}
             onRemoveFromAssetsClick={handleRemoveFromAssets}
             onReportDownloadClick={handleOpenDownloadReportDialog}
             onSortChange={handleSortChange}
@@ -538,12 +509,12 @@ const ReportDetails = props => {
         )}
       </TargetComponent>
       {showFilterDialog && (
-        <FilterDialog
+        <ReportDetailsFilterDialog
           audit={true}
           createFilterType="result"
           delta={false}
           filter={reportFilter}
-          onCloseClick={handleFilterDialogClose}
+          onClose={handleFilterDialogClose}
           onFilterChanged={handleFilterChange}
           onFilterCreated={handleFilterCreated}
         />
@@ -636,7 +607,7 @@ const ReportDetailsWrapper = props => {
   return (
     <FilterProvider
       fallbackFilter={DEFAULT_FILTER}
-      gmpname="result"
+      gmpName="result"
       pageName={`report-${reportId}`}
     >
       {({filter}) => (
