@@ -3,16 +3,15 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
-import {TASK_STATUS} from 'gmp/models/task';
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
 import styled from 'styled-components';
+import {TASK_STATUS} from 'gmp/models/task';
+import {isDefined} from 'gmp/utils/identity';
 import StatusBar from 'web/components/bar/StatusBar';
 import ToolBar from 'web/components/bar/Toolbar';
 import DateTime from 'web/components/date/DateTime';
 import ErrorPanel from 'web/components/error/ErrorPanel';
-import ReportIcon from 'web/components/icon/ReportIcon';
+import {ReportIcon} from 'web/components/icon';
 import Divider from 'web/components/layout/Divider';
 import Layout from 'web/components/layout/Layout';
 import Loading from 'web/components/loading/Loading';
@@ -25,8 +24,10 @@ import TabList from 'web/components/tab/TabList';
 import TabPanel from 'web/components/tab/TabPanel';
 import TabPanels from 'web/components/tab/TabPanels';
 import Tabs from 'web/components/tab/Tabs';
+import TabsContainer from 'web/components/tab/TabsContainer';
 import EntityInfo from 'web/entity/EntityInfo';
 import EntityTags from 'web/entity/Tags';
+import useTranslation from 'web/hooks/useTranslation';
 import ApplicationsTab from 'web/pages/reports/details/ApplicationsTab';
 import ClosedCvesTab from 'web/pages/reports/details/ClosedCvesTab';
 import CvesTab from 'web/pages/reports/details/CvesTab';
@@ -42,13 +43,21 @@ import TLSCertificatesTab from 'web/pages/reports/details/TlsCertificatesTab';
 import ToolBarIcons from 'web/pages/reports/details/ToolbarIcons';
 import PropTypes from 'web/utils/PropTypes';
 import withGmp from 'web/utils/withGmp';
-
 const Span = styled.span`
   margin-top: 2px;
 `;
 
+const HeaderContainer = styled.div`
+  display: flex;
+  flex-direction: row;
+  align-items: center;
+  gap: 8px;
+  white-space: normal;
+  word-break: normal;
+  word-wrap: break-word;
+`;
+
 const PageContent = ({
-  activeTab,
   applicationsCounts,
   closedCvesCounts,
   cvesCounts,
@@ -74,7 +83,6 @@ const PageContent = ({
   showSuccessMessage,
   task,
   tlsCertificatesCounts,
-  onActivateTab,
   onAddToAssetsClick,
   onTlsCertificateDownloadClick,
   onError,
@@ -86,13 +94,14 @@ const PageContent = ({
   onFilterRemoveSeverityClick,
   onFilterRemoveClick,
   onFilterResetClick,
-  onInteraction,
+
   onRemoveFromAssetsClick,
   onReportDownloadClick,
   onSortChange,
   onTagSuccess,
   onTargetEditClick,
 }) => {
+  const [_] = useTranslation();
   const hasReport = isDefined(entity);
 
   const report = hasReport ? entity.report : undefined;
@@ -140,24 +149,28 @@ const PageContent = ({
     !showThresholdMessage &&
     (!isDefined(results.entities) || results.entities.length === 0);
 
-  const header_title = (
+  const HeaderTitle = (
     <Divider>
-      <span>{_('Report:')}</span>
+      <span style={{whiteSpace: 'nowrap'}}>{_('Report:')}</span>
       {showIsLoading ? (
         <span>{_('Loading')}</span>
       ) : (
-        <Divider>
-          <DateTime date={timestamp} />
+        <HeaderContainer>
+          <DateTime showTimezoneAsSeparateLine date={timestamp} />
           <Span>
             <StatusBar progress={progress} status={status} />
           </Span>
-        </Divider>
+        </HeaderContainer>
       )}
     </Divider>
   );
 
   const header = (
-    <SectionHeader img={<ReportIcon size="large" />} title={header_title}>
+    <SectionHeader
+      alignHeading={['start', 'baseline']}
+      img={<ReportIcon size="large" />}
+      title={HeaderTitle}
+    >
       {hasReport && <EntityInfo entity={entity} />}
     </SectionHeader>
   );
@@ -178,7 +191,6 @@ const PageContent = ({
           task={task}
           threshold={threshold}
           onAddToAssetsClick={onAddToAssetsClick}
-          onInteraction={onInteraction}
           onRemoveFromAssetsClick={onRemoveFromAssetsClick}
           onReportDownloadClick={onReportDownloadClick}
         />
@@ -205,13 +217,9 @@ const PageContent = ({
         {showIsLoading ? (
           <Loading />
         ) : (
-          <React.Fragment>
+          <TabsContainer flex="column" grow="1">
             <TabLayout align={['start', 'end']} grow="1">
-              <TabList
-                active={activeTab}
-                align={['start', 'stretch']}
-                onActivateTab={onActivateTab}
-              >
+              <TabList align={['start', 'stretch']}>
                 <Tab>{_('Information')}</Tab>
                 <Tab>
                   <TabTitle counts={resultsCounts} title={_('Results')} />
@@ -259,7 +267,7 @@ const PageContent = ({
             </TabLayout>
 
             {hasReport ? (
-              <Tabs active={activeTab}>
+              <Tabs>
                 <TabPanels>
                   <TabPanel>
                     <Summary
@@ -288,7 +296,6 @@ const PageContent = ({
                       onFilterEditClick={onFilterEditClick}
                       onFilterRemoveClick={onFilterRemoveClick}
                       onFilterRemoveSeverityClick={onFilterRemoveSeverityClick}
-                      onInteraction={onInteraction}
                       onSortChange={sortField =>
                         onSortChange('results', sortField)
                       }
@@ -315,7 +322,6 @@ const PageContent = ({
                         isUpdating={isUpdating}
                         sortField={sorting.hosts.sortField}
                         sortReverse={sorting.hosts.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('hosts', sortField)
                         }
@@ -342,7 +348,6 @@ const PageContent = ({
                         ports={ports.entities}
                         sortField={sorting.ports.sortField}
                         sortReverse={sorting.ports.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('ports', sortField)
                         }
@@ -369,7 +374,6 @@ const PageContent = ({
                         isUpdating={isUpdating}
                         sortField={sorting.apps.sortField}
                         sortReverse={sorting.apps.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('apps', sortField)
                         }
@@ -396,7 +400,6 @@ const PageContent = ({
                         operatingsystems={operatingsystems.entities}
                         sortField={sorting.os.sortField}
                         sortReverse={sorting.os.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('os', sortField)
                         }
@@ -423,7 +426,6 @@ const PageContent = ({
                         isUpdating={isUpdating}
                         sortField={sorting.cves.sortField}
                         sortReverse={sorting.cves.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('cves', sortField)
                         }
@@ -450,7 +452,6 @@ const PageContent = ({
                         isUpdating={isUpdating}
                         sortField={sorting.closedcves.sortField}
                         sortReverse={sorting.closedcves.sortReverse}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('closedcves', sortField)
                         }
@@ -477,7 +478,6 @@ const PageContent = ({
                         sortField={sorting.tlscerts.sortField}
                         sortReverse={sorting.tlscerts.sortReverse}
                         tlsCertificates={tlsCertificates.entities}
-                        onInteraction={onInteraction}
                         onSortChange={sortField =>
                           onSortChange('tlscerts', sortField)
                         }
@@ -495,7 +495,6 @@ const PageContent = ({
                       isUpdating={isUpdating}
                       sortField={sorting.errors.sortField}
                       sortReverse={sorting.errors.sortReverse}
-                      onInteraction={onInteraction}
                       onSortChange={sortField =>
                         onSortChange('errors', sortField)
                       }
@@ -506,7 +505,6 @@ const PageContent = ({
                       entity={report}
                       onChanged={onTagSuccess}
                       onError={onError}
-                      onInteraction={onInteraction}
                     />
                   </TabPanel>
                 </TabPanels>
@@ -514,7 +512,7 @@ const PageContent = ({
             ) : (
               <Loading />
             )}
-          </React.Fragment>
+          </TabsContainer>
         )}
       </Section>
     </Layout>
@@ -522,7 +520,6 @@ const PageContent = ({
 };
 
 PageContent.propTypes = {
-  activeTab: PropTypes.number,
   applicationsCounts: PropTypes.counts,
   closedCvesCounts: PropTypes.counts,
   cvesCounts: PropTypes.counts,
@@ -548,7 +545,6 @@ PageContent.propTypes = {
   sorting: PropTypes.object,
   task: PropTypes.model,
   tlsCertificatesCounts: PropTypes.counts,
-  onActivateTab: PropTypes.func.isRequired,
   onAddToAssetsClick: PropTypes.func.isRequired,
   onError: PropTypes.func.isRequired,
   onFilterAddLogLevelClick: PropTypes.func.isRequired,
@@ -559,7 +555,6 @@ PageContent.propTypes = {
   onFilterRemoveClick: PropTypes.func.isRequired,
   onFilterRemoveSeverityClick: PropTypes.func.isRequired,
   onFilterResetClick: PropTypes.func.isRequired,
-  onInteraction: PropTypes.func.isRequired,
   onRemoveFromAssetsClick: PropTypes.func.isRequired,
   onReportDownloadClick: PropTypes.func.isRequired,
   onSortChange: PropTypes.func.isRequired,
