@@ -3,7 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import _ from 'gmp/locale';
+import React from 'react';
+import {connect} from 'react-redux';
 import logger from 'gmp/log';
 import Filter, {
   ALL_FILTER,
@@ -13,19 +14,17 @@ import Filter, {
 import {isActive} from 'gmp/models/task';
 import {first} from 'gmp/utils/array';
 import {isDefined, hasValue} from 'gmp/utils/identity';
-import React from 'react';
-import {connect} from 'react-redux';
 import withDownload from 'web/components/form/withDownload';
 import PageTitle from 'web/components/layout/PageTitle';
 import Reload, {
   NO_RELOAD,
   USE_DEFAULT_RELOAD_INTERVAL_ACTIVE,
 } from 'web/components/loading/Reload';
-import withDialogNotification from 'web/components/notification/withDialogNotifiaction';
+import withDialogNotification from 'web/components/notification/withDialogNotification';
 import FilterProvider from 'web/entities/FilterProvider';
 import Page from 'web/pages/reports/DetailsContent';
-import ReportDetailsFilterDialog from 'web/pages/reports/DetailsFilterDialog';
 import DownloadReportDialog from 'web/pages/reports/DownloadReportDialog';
+import ReportDetailsFilterDialog from 'web/pages/reports/ReportDetailsFilterDialog';
 import TargetComponent from 'web/pages/targets/Component';
 import {
   loadAllEntities as loadFilters,
@@ -45,7 +44,6 @@ import {pageFilter as setPageFilter} from 'web/store/pages/actions';
 import getPage from 'web/store/pages/selectors';
 import {
   loadReportComposerDefaults,
-  renewSessionTimeout,
   saveReportComposerDefaults,
 } from 'web/store/usersettings/actions';
 import {getUserSettingsDefaultFilter} from 'web/store/usersettings/defaultfilters/selectors';
@@ -61,7 +59,7 @@ import PropTypes from 'web/utils/PropTypes';
 import {generateFilename} from 'web/utils/Render';
 import withGmp from 'web/utils/withGmp';
 import {withRouter} from 'web/utils/withRouter';
-
+import withTranslation from 'web/utils/withTranslation';
 
 const log = logger.getLogger('web.pages.report./DetailsPage');
 
@@ -91,7 +89,6 @@ class ReportDetails extends React.Component {
     super(...args);
 
     this.state = {
-      activeTab: 0,
       showFilterDialog: false,
       showDownloadReportDialog: false,
       sorting: {
@@ -134,7 +131,6 @@ class ReportDetails extends React.Component {
       },
     };
 
-    this.handleActivateTab = this.handleActivateTab.bind(this);
     this.handleAddToAssets = this.handleAddToAssets.bind(this);
     this.handleChanged = this.handleChanged.bind(this);
     this.handleError = this.handleError.bind(this);
@@ -222,6 +218,8 @@ class ReportDetails extends React.Component {
   }
 
   componentDidUpdate(prevProps) {
+    const {_} = this.props;
+
     const {reportFormats} = this.props;
     if (
       !isDefined(this.state.reportFormatId) &&
@@ -290,8 +288,6 @@ class ReportDetails extends React.Component {
   }
 
   handleFilterChange(filter) {
-    this.handleInteraction();
-
     this.load(filter);
   }
 
@@ -307,16 +303,10 @@ class ReportDetails extends React.Component {
     }
   }
 
-  handleActivateTab(index) {
-    this.handleInteraction();
-
-    this.setState({activeTab: index});
-  }
-
   handleAddToAssets() {
-    const {gmp, showSuccessMessage, entity, reportFilter: filter} = this.props;
+    const {_} = this.props;
 
-    this.handleInteraction();
+    const {gmp, showSuccessMessage, entity, reportFilter: filter} = this.props;
 
     gmp.report.addAssets(entity, {filter}).then(() => {
       showSuccessMessage(
@@ -329,9 +319,9 @@ class ReportDetails extends React.Component {
   }
 
   handleRemoveFromAssets() {
-    const {gmp, showSuccessMessage, entity, reportFilter: filter} = this.props;
+    const {_} = this.props;
 
-    this.handleInteraction();
+    const {gmp, showSuccessMessage, entity, reportFilter: filter} = this.props;
 
     gmp.report.removeAssets(entity, {filter}).then(() => {
       showSuccessMessage(_('Report content removed from Assets.'));
@@ -340,14 +330,10 @@ class ReportDetails extends React.Component {
   }
 
   handleFilterEditClick() {
-    this.handleInteraction();
-
     this.setState({showFilterDialog: true});
   }
 
   handleFilterDialogClose() {
-    this.handleInteraction();
-
     this.setState({showFilterDialog: false});
   }
 
@@ -403,8 +389,6 @@ class ReportDetails extends React.Component {
       ? report_format.extension
       : 'unknown'; // unknown should never happen but we should be save here
 
-    this.handleInteraction();
-
     return gmp.report
       .download(entity, {
         reportConfigId,
@@ -435,8 +419,6 @@ class ReportDetails extends React.Component {
 
     const {data, serial} = cert;
 
-    this.handleInteraction();
-
     onDownload({
       filename: 'tls-cert-' + serial + '.pem',
       mimetype: 'application/x-x509-ca-cert',
@@ -445,7 +427,6 @@ class ReportDetails extends React.Component {
   }
 
   handleFilterCreated(filter) {
-    this.handleInteraction();
     this.load(filter);
     this.props.loadFilters();
   }
@@ -454,8 +435,6 @@ class ReportDetails extends React.Component {
     const {reportFilter} = this.props;
     let levels = reportFilter.get('levels', '');
 
-    this.handleInteraction();
-
     if (!levels.includes('g')) {
       levels += 'g';
       const lfilter = reportFilter.copy();
@@ -467,8 +446,6 @@ class ReportDetails extends React.Component {
   handleFilterRemoveSeverity() {
     const {reportFilter} = this.props;
 
-    this.handleInteraction();
-
     if (reportFilter.has('severity')) {
       const lfilter = reportFilter.copy();
       lfilter.delete('severity');
@@ -479,8 +456,6 @@ class ReportDetails extends React.Component {
   handleFilterDecreaseMinQoD() {
     const {reportFilter} = this.props;
 
-    this.handleInteraction();
-
     if (reportFilter.has('min_qod')) {
       const lfilter = reportFilter.copy();
       lfilter.set('min_qod', 30);
@@ -489,8 +464,6 @@ class ReportDetails extends React.Component {
   }
 
   handleSortChange(name, sortField) {
-    this.handleInteraction();
-
     const prev = this.state.sorting[name];
 
     const sortReverse =
@@ -507,13 +480,6 @@ class ReportDetails extends React.Component {
     });
   }
 
-  handleInteraction() {
-    const {onInteraction} = this.props;
-    if (isDefined(onInteraction)) {
-      onInteraction();
-    }
-  }
-
   loadTarget() {
     const {entity} = this.props;
     const target = getTarget(entity);
@@ -522,6 +488,8 @@ class ReportDetails extends React.Component {
   }
 
   render() {
+    const {_} = this.props;
+
     const {
       filters = [],
       gmp,
@@ -532,14 +500,13 @@ class ReportDetails extends React.Component {
       reportError,
       reportFormats,
       reportId,
-      onInteraction,
+
       reportComposerDefaults,
       showError,
       showErrorMessage,
       showSuccessMessage,
     } = this.props;
     const {
-      activeTab,
       applicationsCounts,
       cvesCounts,
       closedCvesCounts,
@@ -567,13 +534,9 @@ class ReportDetails extends React.Component {
     return (
       <React.Fragment>
         <PageTitle title={_('Report Details')} />
-        <TargetComponent
-          onError={this.handleError}
-          onInteraction={onInteraction}
-        >
+        <TargetComponent onError={this.handleError}>
           {({edit}) => (
             <Page
-              activeTab={activeTab}
               applicationsCounts={applicationsCounts}
               closedCvesCounts={closedCvesCounts}
               cvesCounts={cvesCounts}
@@ -598,7 +561,6 @@ class ReportDetails extends React.Component {
               sorting={sorting}
               task={isDefined(report) ? report.task : undefined}
               tlsCertificatesCounts={tlsCertificatesCounts}
-              onActivateTab={this.handleActivateTab}
               onAddToAssetsClick={this.handleAddToAssets}
               onError={this.handleError}
               onFilterAddLogLevelClick={this.handleFilterAddLogLevel}
@@ -609,7 +571,6 @@ class ReportDetails extends React.Component {
               onFilterRemoveClick={this.handleFilterRemoveClick}
               onFilterRemoveSeverityClick={this.handleFilterRemoveSeverity}
               onFilterResetClick={this.handleFilterResetClick}
-              onInteraction={onInteraction}
               onRemoveFromAssetsClick={this.handleRemoveFromAssets}
               onReportDownloadClick={this.handleOpenDownloadReportDialog}
               onSortChange={this.handleSortChange}
@@ -682,7 +643,7 @@ ReportDetails.propTypes = {
   target: PropTypes.model,
   username: PropTypes.string,
   onDownload: PropTypes.func.isRequired,
-  onInteraction: PropTypes.func.isRequired,
+  _: PropTypes.func.isRequired,
 };
 
 const reloadInterval = report =>
@@ -725,10 +686,12 @@ const load =
     return loadReportWithThreshold(reportId, {filter});
   };
 
+const TranslatedReportDetails = withTranslation(ReportDetails);
+
 const ReportDetailsWrapper = ({reportFilter, ...props}) => (
   <FilterProvider
     fallbackFilter={DEFAULT_FILTER}
-    gmpname="result"
+    gmpName="result"
     pageName={`report-${props.reportId}`}
   >
     {({filter}) => (
@@ -739,7 +702,7 @@ const ReportDetailsWrapper = ({reportFilter, ...props}) => (
         reloadInterval={() => reloadInterval(props.entity)}
       >
         {({reload}) => (
-          <ReportDetails
+          <TranslatedReportDetails
             {...props}
             defaultFilter={filter}
             reload={reload}
@@ -761,7 +724,6 @@ ReportDetailsWrapper.propTypes = {
 const getReportPageName = id => `report-${id}`;
 
 const mapDispatchToProps = (dispatch, {gmp, params}) => ({
-  onInteraction: () => dispatch(renewSessionTimeout(gmp)()),
   loadFilters: () => dispatch(loadFilters(gmp)(RESULTS_FILTER_FILTER)),
   loadSettings: () => dispatch(loadUserSettingDefaults(gmp)()),
   loadTarget: targetId => gmp.target.get({id: targetId}),
@@ -822,6 +784,7 @@ const mapStateToProps = (rootState, {params}) => {
 };
 
 export default compose(
+  withTranslation,
   withGmp,
   withDialogNotification,
   withDownload,
