@@ -4,9 +4,9 @@
  */
 
 import {_l} from 'gmp/locale/lang';
-import {createEntitiesFooter} from 'web/entities/Footer';
-import {createEntitiesHeader} from 'web/entities/Header';
-import {createEntitiesTable} from 'web/entities/Table';
+import createEntitiesFooter from 'web/entities/createEntitiesFooter';
+import createEntitiesHeader from 'web/entities/createEntitiesHeader';
+import createEntitiesTable from 'web/entities/createEntitiesTable';
 import withRowDetails from 'web/entities/withRowDetails';
 import ScannerDetails from 'web/pages/scanners/Details';
 import Row from 'web/pages/scanners/Row';
