@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {createAll} from './utils/main';
+import {createAll} from 'web/store/entities/utils/main';
 
 const {
   loadAllEntities,
@@ -24,5 +24,3 @@ export {
   entitiesLoadingActions,
   entityLoadingActions,
 };
-
-// vim: set ts=2 sw=2 tw=80:
