@@ -7,7 +7,6 @@ import {isDefined} from 'gmp/utils/identity';
 import {types} from 'web/store/entities/utils/actions';
 import {filterIdentifier} from 'web/store/utils';
 
-
 /**
  * Return true if error is not a Rejection class or if Rejection class has a
  * reason of error
@@ -91,13 +90,14 @@ export const createReducer = entityType => {
 
   const entities = (state = {}, action) => {
     switch (action.type) {
-      case types.ENTITIES_LOADING_SUCCESS:
+      case types.ENTITIES_LOADING_SUCCESS: {
         const {data = [], counts, loadedFilter} = action;
         return {
           ids: data.map(entity => entity.id),
           counts,
           loadedFilter,
         };
+      }
       default:
         return state;
     }
@@ -105,24 +105,26 @@ export const createReducer = entityType => {
 
   const byId = (state = {}, action) => {
     switch (action.type) {
-      case types.ENTITIES_LOADING_SUCCESS:
+      case types.ENTITIES_LOADING_SUCCESS: {
         const {data = []} = action;
         const nextState = {
           ...state,
         };
         data.forEach(d => (nextState[d.id] = d));
         return nextState;
+      }
       case types.ENTITY_LOADING_SUCCESS:
         return {
           ...state,
           [action.id]: action.data,
         };
-      case types.ENTITY_DELETE_SUCCESS:
+      case types.ENTITY_DELETE_SUCCESS: {
         const nState = {
           ...state,
         };
         delete nState[action.id];
         return nState;
+      }
       default:
         return state;
     }
