@@ -3,8 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
+import {isDefined} from 'gmp/utils/identity';
+import {updateDisplayName} from 'web/utils/displayName';
 import PropTypes from 'web/utils/PropTypes';
 
 export const withPrefix = Component => {
@@ -21,7 +22,7 @@ export const withPrefix = Component => {
     prefix: PropTypes.string,
   };
 
-  return ComponentPrefixWrapper;
+  return updateDisplayName(ComponentPrefixWrapper, Component, 'withPrefix');
 };
 
 export default withPrefix;
